==> enterprisemodules-ora_config-3.18.4.tar.gz: enterprisemodules-ora_config-3.18.4/lib/puppet/type/shared/ora_config/revoked_with_admin.rb <==
# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:revoked_with_admin, :array_matching => :all) do
  include EasyType
  include Puppet_X::EnterpriseModules::Oracle::Mungers::Upcase
  include Puppet_X::EnterpriseModules::Oracle::GrantProperty
  include Puppet_X::EnterpriseModules::Oracle::Access

  to_translate_to_resource do |_raw_resource|
    #
    # We don't need a value, but we do need the side effects of the super method.
    #
    @all_rights ||= privileges + granted_roles
    nil
  end

  validate do |value|
    fail 'You need to specify an Array instead of a comma separated string' if value =~ /,/
  end

  desc <<-DESC
    The grants you want to make sure are revoked from the `ora_user` or `ora_role`. It is different from the
    `grants` property in the sense that this is not a full list of the rights, but just the rights
    that are **NOT** granted to the user

    Here is an example when using `ora_user`:

        ora_user {'scott':
          ...
          revoked_with_admin => ['GRANT ANY ROLE'],
        }

    Here is an example when using `ora_role`:

        ora_role {'scott':
          ...
          revoked_with_admin => ['GRANT ANY ROLE'],
        }

      **WARNING**

      When you us both the `grants_with_admin` and `revoked_with_admin` property, Puppet will give you a warning about conflicting values. In the end it **WILL** ensure
      that the rights specified for the `revoked_with_admin` property are removed. This way ensuring the most secure configuration.

  DESC

  data_type('Optional[Array[String[1]]]')

  #
  # This property manages grants without admin options
  #
  def self.admin
    true
  end

  def self.common
    false
  end

  def insync?(_is)
    should.none? { |r| current_rights.include?(r) }
  end

  def revoked_rights
    current_rights & value
  end
end

==> enterprisemodules-ora_config-3.20.0.tar.gz: enterprisemodules-ora_config-3.20.0/lib/puppet/type/shared/ora_config/revoked_with_admin.rb <==
# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:revoked_with_admin, :array_matching => :all) do
  include EasyType
  include Puppet_X::EnterpriseModules::Oracle::Mungers::Upcase
  include Puppet_X::EnterpriseModules::Oracle::GrantProperty
  include Puppet_X::EnterpriseModules::Oracle::Access

  to_translate_to_resource do |_raw_resource|
    #
    # We don't need a value, but we do need the side effects of the super method.
    #
    @all_rights ||= privileges + granted_roles
    nil
  end

  validate do |value|
    fail 'You need to specify an Array instead of a comma separated string' if /,/.match?(value.to_s)
  end

  desc <<-DESC
    The grants you want to make sure are revoked from the `ora_user` or `ora_role`. It is different from the
    `grants` property in the sense that this is not a full list of the rights, but just the rights
    that are **NOT** granted to the user

    Here is an example when using `ora_user`:

        ora_user {'scott':
          ...
          revoked_with_admin => ['GRANT ANY ROLE'],
        }

    Here is an example when using `ora_role`:

        ora_role {'scott':
          ...
          revoked_with_admin => ['GRANT ANY ROLE'],
        }

      **WARNING**

      When you us both the `grants_with_admin` and `revoked_with_admin` property, Puppet will give you a warning about conflicting values. In the end it **WILL** ensure
      that the rights specified for the `revoked_with_admin` property are removed. This way ensuring the most secure configuration.

  DESC

  data_type('Optional[Array[String[1]]]')

  #
  # This property manages grants without admin options
  #
  def self.admin
    true
  end

  def self.common
    false
  end

  def insync?(_is)
    should.none? { |r| current_rights.include?(r) }
  end

  def revoked_rights
    current_rights & value
  end
end
